/*
 * Copyright (c) 2004, Jeamy Lee, Austria.
 * JASCOM: Ascom for Java
 * Subproject of EOAUI (Extended Open Astronomical User Interface)
 * Version ALPHA 2
 * mailto:jascom.bugs@jeamy.com. All rights reserved.
 * Source and binaries could be found at
 * http://home.textdesign.com/jeamy/jascom/jascom.jar
 * For more information and/or support and bug reports/suggestions use the email above.
 *
 * JASCOM depends on the JACOB (JAva-COM Bridge) libraries
 * programmed by Dan Adler (Copyright (c) 1999) located at
 * http://danadler.com/jacob/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Redistributions in any form must be accompanied by information on
 *    how to obtain complete source code for the JASCOM software.
 *
 * Redistribution of the JASCOM software is not permitted as part of any
 * commercial product that is targeted primarily at Java developers.
 * Such products include, but are not limited to: Java virtual machines,
 * integrated development environments, code libraries, and application
 * server products. Licensing terms for such distribution may be
 * obtained from the copyright holder.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package com.jeamy.jascom;

import com.jacob.activeX.*;
import com.jacob.com.*;
import com.jeamy.jascom.wrap.*;

/**
 *
 * <p>Title: JASCOM: Ascom for Java</p>
 * <p>Description: Java to Ascom Wrapper</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: EOAUI</p>
 * @author Jeamy Lee
 * @version ALPHA 2
 */

// Available methods and properties are described in the
// ASCOM Telescope Interface Standard 2.0 Programmer's Reference
// Available at http://ascom-standards.org/index.html
// and in the ASCOM developer directory tree

public class Properties
{
  protected String driverID = null;
  protected COMDispatcher comDispatcher = null;
  private ActiveXComponent properties = null;

  /**
   * Properties
   */
  protected Properties()
  {
  }

  /**
   * Properties
   *
   * @param driverID String
   */
  public Properties(String driverID)
  {
	this.driverID = driverID;
	properties = new ActiveXComponent(this.driverID);
	comDispatcher = new COMDispatcher(properties);
  }

//  private void setSlewing(boolean Slewing)
//  {
//  }

  public boolean slewing()
  {
	return comDispatcher.get("Slewing").toBoolean();
  }

//  private void setName(String Name)
//  {
//  }

  public String name()
  {
	return comDispatcher.get("Name").toString();
  }

//  private void setInterfaceVersion(int InterfaceVersion)
//  {
//  }

  public int interfaceVersion()
  {
	return comDispatcher.get("InterfaceVersion").toInt();
  }

//  private void setDriverVersion(String DriverVersion)
//  {
//  }

  public String driverVersion()
  {
	return comDispatcher.get("DriverVersion").toString();
  }

//  private void setDriverInfo(String DriverInfo)
//  {
//  }

  public String driverInfo()
  {
	return comDispatcher.get("DriverInfo").toString();
  }

//  private void setDescription(String Description)
//  {
//  }

  public String description()
  {
	return comDispatcher.get("Description").toString();
  }

  public void setConnected(boolean Connected)
  {
	comDispatcher.put("Connected", new Variant(Connected));
  }

  public boolean connected()
  {
	return comDispatcher.get("Connected").toBoolean();
  }

  public boolean canSetPark()
  {
	return comDispatcher.get("CanSetPark").toBoolean();
  }

//  private void setCanSetPark(boolean canSetPark)
//  {
//  }

//  private void setCanPark(boolean canPark)
//  {
//  }

  public boolean canPark()
  {
	return comDispatcher.get("CanPark").toBoolean();
  }

//  private void setCanFindHome(boolean canFindHome)
//  {
//  }

  public boolean canFindHome()
  {
	return comDispatcher.get("CanFindHome").toBoolean();
  }

//  private void setAzimuth(double Azimuth)
//  {
//  }

  public double azimuth()
  {
	return comDispatcher.get("Azimuth").toDouble();
  }

//  private void setAtPark(boolean AtPark)
//  {
//  }

  public boolean atPark()
  {

	return comDispatcher.get("AtPark").toBoolean();
  }

//  private void setAtHome(boolean AtHome)
//  {
//  }

  public boolean atHome()
  {
	return comDispatcher.get("AtHome").toBoolean();
  }

//  private void setAltitude(double Altitude)
//  {
//  }

  public double altitude()
  {
	return comDispatcher.get("Altitude").toDouble();
  }

  /**
   * close
   */
  public void close()
  {
	properties.release();
  }
}
