/*
 * Copyright (c) 2004 Jeamy Lee, Austria.
 * JASCOM: Ascom for Java
 * Subproject of EOAUI (Extended Open Astronomical User Interface)
 * Version ALPHA 2
 * mailto:jascom.bugs@jeamy.com. All rights reserved.
 * Source and binaries could be found at
 * http://home.textdesign.com/jeamy/jascom/jascom.jar
 * For more information and/or support and bug reports use above email.
 *
 * JASCOM depends on the JACOB (JAva-COM Bridge) libraries
 * programmed by Dan Adler (Copyright (c) 1999) located at
 * http://danadler.com/jacob/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Redistributions in any form must be accompanied by information on
 *    how to obtain complete source code for the JASCOM software.
 *
 * Redistribution of the JASCOM software is not permitted as part of any
 * commercial product that is targeted primarily at Java developers.
 * Such products include, but are not limited to: Java virtual machines,
 * integrated development environments, code libraries, and application
 * server products. Licensing terms for such distribution may be
 * obtained from the copyright holder.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package com.jeamy.jascom;

import java.util.*;

import com.jacob.com.*;
import com.jeamy.jascom.wrap.*;
import com.jeamy.jascom.exceptions.JascomException;

/**
 *
 * <p>Title: JASCOM: Ascom for Java</p>
 * <p>Description: Java to Ascom Wrapper</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: EOAUI</p>
 * @author Jeamy Lee
 * @version ALPHA 2
 */

// Available methods and properties are described in the
// ASCOM Telescope Interface Standard 2.0 Programmer's Reference
// Available at http://ascom-standards.org/index.html
// and in the ASCOM developer directory tree

public class Telescope extends TelescopeProperties
{
  /**
   * Telescope
   */
	public Telescope()
	{
		super("ScopeSim.Telescope");
	}
  /**
   *
   * Telescope
   * @param driverID String
   */
  public Telescope(String driverID)
  {
	  super(driverID);
	  //	this.driverID = driverID;
  }

  /**
   * abortSlew
   */
  public void abortSlew()
  {
	comDispatcher.process("AbortSlew").noParam();
  }

  /**
   * axisRates
   *
   * @param axis TelescopeAxes
   * @return List
   */
  public List axisRates(TelescopeAxes axis)
  {
	System.out.println("Axis: " + axis.enumb);

	/** @todo utility methods for accessing collections */

	Object o = comDispatcher.process("AxisRates", new Variant[]
									 {new Variant(axis.enumb)});

	return null;
  }

  /**
   * canMoveAxis
   *
   * @param axis TelescopeAxes
   * @return boolean
   */
  public boolean canMoveAxis(TelescopeAxes axis)
  {
	return comDispatcher.process("CanMoveAxis", new Variant[]
								 {new Variant(axis.enumb)}).toBoolean();
  }

  /**
   * commandBlind
   *
   * @param command String
   */
  public void commandBlind(String command)
  {
	commandBlind(command, false);
  }

  /**
   * commandBlind
   *
   * @param command String
   * @param raw boolean
   */
  public void commandBlind(String command, boolean raw)
  {
	comDispatcher.process("CommandBlind", new Variant[]
						  {new Variant(command), new Variant(raw)}).noParam();
  }

  /**
   * commandBool
   *
   * @param command String
   */
  public boolean commandBool(String command)
  {
	return commandBool(command, false);
  }

  /**
   * commandBool
   *
   * @param command String
   * @param raw boolean
   */
  public boolean commandBool(String command, boolean raw)
  {
	return comDispatcher.process("CommandBool", new Variant[]
								 {new Variant(command), new Variant(raw)}).toBoolean();
  }

  /**
   * CommandString
   *
   * @param command String
   */
  public String commandString(String command)
  {
	return commandString(command, false);
  }

  /**
   * commandString
   *
   * @param command String
   * @param raw boolean
   */
  public String commandString(String command, boolean raw)
  {
	return comDispatcher.process("CommandString", new Variant[]
								 {new Variant(command), new Variant(raw)}).toString();
  }

  /**
   * pulseGuide
   *
   * @param direction GuideDirections
   * @param duration long
   */
  public void pulseGuide(GuideDirections direction, long duration)
  {
	System.out.println("GuideDirections: " + direction.enumb);
	comDispatcher.process("PulseGuide", new Variant[]
						  {new Variant(direction.enumb), new Variant(duration)}).noParam();
  }

  /**
   * findHome
   */
  public void findHome()
  {
	comDispatcher.process("FindHome").noParam();
  }

  /**
   * destinationSideOfPier
   *
   * @param rightAscension double
   * @param declination double
   * @return PierSide
   */
  public PierSide destinationSideOfPier(double rightAscension, double declination) throws JascomException
  {
	int p = comDispatcher.process("DestinationSideOfPier", new Variant[]
								  {new Variant(rightAscension), new Variant(declination)}).toInt();
	return PierSide.getPierSide(p);
  }

  /**
   * setPark
   */
  public void setPark()
  {
	comDispatcher.process("SetPark").noParam();
  }

  /**
   * slewToCoordinates
   *
   * @param rightAscension double
   * @param declination double
   */
  public void slewToCoordinates(double rightAscension, double declination)
  {
	comDispatcher.process("SlewToCoordinates", new Variant[]
						  {new Variant(rightAscension), new Variant(declination)}).noParam();
  }

  /**
   * slewToCoordinatesAsync
   *
   * @param rightAscension double
   * @param declination double
   */
  public void slewToCoordinatesAsync(double rightAscension, double declination)
  {
	comDispatcher.process("SlewToCoordinatesAsync", new Variant[]
						  {new Variant(rightAscension), new Variant(declination)}).noParam();
  }

  /**
   * slewToTarget
   */
  public void slewToTarget()
  {
	comDispatcher.process("SlewToTarget").noParam();
  }

  /**
   * slewToTargetAsync
   */
  public void slewToTargetAsync()
  {
	comDispatcher.process("SlewToTargetAsync").noParam();
  }

  /**
   * syncToAltAz
   *
   * @param azimuth double
   * @param altitude double
   */
  public void syncToAltAz(double azimuth, double altitude)
  {
	comDispatcher.process("SyncToAltAz", new Variant[]
						  {new Variant(azimuth), new Variant(altitude)}).noParam();
  }

  /**
   * syncToCoordinates
   *
   * @param rightAscension double
   * @param declination double
   */
  public void syncToCoordinates(double rightAscension, double declination)
  {
	comDispatcher.process("SyncToCoordinates", new Variant[]
						  {new Variant(rightAscension), new Variant(rightAscension)}).noParam();
  }

  /**
   * unpark
   */
  public void unpark()
  {
	comDispatcher.process("Unpark").noParam();
  }

  /**
   * syncToTarget
   */
  public void syncToTarget()
  {
	comDispatcher.process("SyncToTarget").noParam();
  }

  /**
   * setupDialog
   */
  public void setupDialog()
  {
	comDispatcher.process("SetupDialog").noParam();
  }

  /**
   * park
   */
  public void park()
  {
	comDispatcher.process("Park").noParam();
  }

  /**
   * moveAxis
   *
   * @param axis TelescopeAxes
   * @param rate double
   */
  public void moveAxis(TelescopeAxes axis, double rate)
  {
	System.out.println("Axis: " + axis.enumb);
	comDispatcher.process("MoveAxis", new Variant[]
						  {new Variant(axis.enumb), new Variant(rate)}).noParam();
  }

  /**
   * slewToAltAz
   *
   * @param azimuth double
   * @param altitude double
   */
  public void slewToAltAz(double azimuth, double altitude)
  {
	comDispatcher.process("SlewToAltAz", new Variant[]
						  {new Variant(azimuth), new Variant(altitude)}).noParam();
  }

  /**
   * slewToAltAzAsync
   *
   * @param azimuth double
   * @param altitude double
   */
  public void slewToAltAzAsync(double azimuth, double altitude)
  {
	comDispatcher.process("SlewToAltAzAsync", new Variant[]
						  {new Variant(azimuth), new Variant(altitude)}).noParam();
  }

  /**
   * close
   */
  public void close()
  {
	super.close();
  }

}
