/*
 * Copyright (c) 2004 Jeamy Lee, Austria.
 * JASCOM: Ascom for Java
 * Subproject of EOAUI (Extended Open Astronomical User Interface)
 * Version ALPHA 2
 * mailto:jascom.bugs@jeamy.com. All rights reserved.
 * Source and binaries could be found at
 * http://home.textdesign.com/jeamy/jascom/jascom.jar
 * For more information and/or support and bug reports use above email.
 *
 * JASCOM depends on the JACOB (JAva-COM Bridge) libraries
 * programmed by Dan Adler (Copyright (c) 1999) located at
 * http://danadler.com/jacob/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Redistributions in any form must be accompanied by information on
 *    how to obtain complete source code for the JASCOM software.
 *
 * Redistribution of the JASCOM software is not permitted as part of any
 * commercial product that is targeted primarily at Java developers.
 * Such products include, but are not limited to: Java virtual machines,
 * integrated development environments, code libraries, and application
 * server products. Licensing terms for such distribution may be
 * obtained from the copyright holder.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package com.jeamy.jascom.helper;

import java.util.HashMap;
import java.util.Map;

import com.jacob.activeX.ActiveXComponent;
import com.jacob.com.SafeArray;
import com.jacob.com.Variant;
import com.jeamy.jascom.wrap.COMDispatcher;

/**
 *
 * <p>Title: JASCOM: Ascom for Java</p>
 * <p>Description: Java to Ascom Wrapper</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: EOAUI</p>
 * @author Jeamy Lee
 * @version ALPHA 2
 */

//
// WARNING !!!
// USE THE Profile CLASS WITH CAUTION.
// IT IS NOT TESTED VERY WELL! PRE ALPHA STATE!
// WARNING !!!
//

public class Profile
{

  private String deviceType = "Telescope";
  private ActiveXComponent util = null;
  private COMDispatcher comDispatcher = null;

  public void setDeviceType(String deviceType)
  {
	this.deviceType = deviceType;
	comDispatcher.put("DeviceType", new Variant(deviceType));
  }

  public String getDeviceType()
  {
	this.deviceType = comDispatcher.get("DeviceType").toString();
	return deviceType;
  }

  public Profile()
  {
	util = new ActiveXComponent("DriverHelper.Profile");
	comDispatcher = new COMDispatcher(util);
  }

  /**
   * createSubKey
   *
   * @param driverID String
   * @param subKey String
   */
  public void createSubKey(String driverID, String subKey)
  {
	comDispatcher.process("CreateSubKey", new Variant[]
		{new Variant(driverID), new Variant(subKey)}).noParam();
  }

  /**
   * deleteSubKey
   *
   * @param driverID String
   * @param subKey String
   */
  public void deleteSubKey(String driverID, String subKey)
  {
	comDispatcher.process("DeleteSubKey", new Variant[]
		{new Variant(driverID), new Variant(subKey)}).noParam();
  }

  /**
   * deleteValue
   *
   * @param driverID String
   * @param name String
   */
  public void deleteValue(String driverID, String name)
  {
	deleteValue(driverID, name, "");
  }

  /**
   * deleteValue
   *
   * @param driverID String
   * @param name String
   * @param subKey String
   */
  public void deleteValue(String driverID, String name, String subKey)
  {
	comDispatcher.process("DeleteValue", new Variant[]
		{new Variant(driverID), new Variant(name), new Variant(subKey)}).noParam();
  }

  /**
   * getValue
   *
   * @param driverID String
   * @param name String
   */
  public String getValue(String driverID, String name)
  {
	return getValue(driverID, name, "");
  }

  /**
   * getValue
   *
   * @param driverID String
   * @param name String
   * @param subKey String
   */
  public String getValue(String driverID, String name, String subKey)
  {
	return comDispatcher.process("GetValue", new Variant[]
		{new Variant(driverID), new Variant(name), new Variant(subKey)}).toString();
  }

  /**
   * ssRegistered
   *
   * @param driverID String
   * @return boolean
   */
  public boolean isRegistered(String driverID)
  {
	return comDispatcher.process("IsRegistered", new Variant[]
		{new Variant(driverID)}).toBoolean();
  }

  /**
   * register
   *
   * @param driverID String
   * @param dDescriptiveName String
   */
  public void register(String driverID, String dDescriptiveName)
  {
	comDispatcher.process("Register", new Variant[]
		{new Variant(driverID), new Variant(dDescriptiveName)}).noParam();
  }

  /**
   * subKeys
   *
   * @param driverID String
   * @return Map
   */
  public Map subKeys(String driverID)
  {
	return subKeys(driverID, "");
  }

  /**
   * subKeys
   *
   * @param driverID String
   * @param subKey String
   * @return Map
   */
  public Map subKeys(String driverID, String subKey)
  {
	Object d = comDispatcher.process("SubKeys", new Variant[]
				  {new Variant(driverID), new Variant(subKey)}).toDispatch();
	return getDictionaryAsMap(d);
  }

  /**
   * values
   *
   * @param driverID String
   * @return Map
   */
  public Map values(String driverID)
  {
	return values(driverID, "");
  }

  /**
   * values
   *
   * @param driverID String
   * @param subKey String
   * @return Map
   */
  public Map values(String driverID, String subKey)
  {
	Object d = comDispatcher.process("Values", new Variant[]
			   {new Variant(driverID), new Variant(subKey)}).toDispatch();

	return getDictionaryAsMap(d);
  }

  /**
   * writeValue
   *
   * @param driverID String
   * @param name String
   * @param value String
   */
  public void writeValue(String driverID, String name, String value)
  {
	writeValue(driverID, name, value, "");
  }

  /**
   * writeValue
   *
   * @param driverID String
   * @param name String
   * @param value String
   * @param subKey String
   */
  public void writeValue(String driverID, String name, String value, String subKey)
  {
	comDispatcher.process("WriteValue", new Variant[]
		{new Variant(driverID), new Variant(name), new Variant(value), new Variant(subKey)}).noParam();
  }

  /**
   * unregister
   *
   * @param driverID String
   */
  public void unregister(String driverID)
  {
	comDispatcher.process("WriteValue", new Variant[]
		{new Variant(driverID)}).noParam();
  }

  /**
   *
   * @param dict Object
   * @return Map
   */
  public Map getDictionaryAsMap(Object dict)
  {
	SafeArray k = comDispatcher.call(dict, "Keys").toSafeArray();
	SafeArray v = comDispatcher.call(dict, "Items").toSafeArray();
	String[] ks = k.toStringArray();
	String[] vs = v.toStringArray();
	Map o = new HashMap();
	for(int i = 0; i < ks.length; i++)
	{
	  o.put(ks[i], vs[i]);
	  System.out.println("Key" + i + ": " + ks[i] + "; Value: " + vs[i]);
	}
	return o;
  }

  /**
   * close
   */
  public void close()
  {
	util.release();
  }

}
