/*
* Copyright (c) 2004 Jeamy Lee, Austria.
* JASCOM: Ascom for Java
* Subproject of EOAUI (Extended Open Astronomical User Interface)
* Version ALPHA 2
* mailto:jascom.bugs@jeamy.com. All rights reserved.
* Source and binaries could be found at
* http://home.textdesign.com/jeamy/jascom/jascom.jar
* For more information and/or support and bug reports use above email.
*
* JASCOM depends on the JACOB (JAva-COM Bridge) libraries
* programmed by Dan Adler (Copyright (c) 1999) located at
* http://danadler.com/jacob/
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
* 3. Redistributions in any form must be accompanied by information on
*    how to obtain complete source code for the JASCOM software.
*
* Redistribution of the JASCOM software is not permitted as part of any
* commercial product that is targeted primarily at Java developers.
* Such products include, but are not limited to: Java virtual machines,
* integrated development environments, code libraries, and application
* server products. Licensing terms for such distribution may be
* obtained from the copyright holder.
*
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE
* FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
* OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
* OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
* OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
* USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*/

package com.jeamy.jascom.helper;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

import com.jacob.activeX.ActiveXComponent;
import com.jacob.com.Variant;
import com.jeamy.jascom.wrap.COMDispatcher;

/**
 *
 * <p>Title: JASCOM: Ascom for Java</p>
 * <p>Description: Java to Ascom Wrapper</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: EOAUI</p>
 * @author Jeamy Lee
 * @version ALPHA 2
 */
public class Util
{
  private ActiveXComponent util = null;
  private COMDispatcher comDispatcher = null;

  public Util()
  {
	util = new ActiveXComponent("DriverHelper.Util");
	comDispatcher = new COMDispatcher(util);
  }

  /**
   * degreesToDM
   *
   * @param degrees double
   * @return String
   */
  public String degreesToDM(double degrees)
  {
	return degreesToDM(degrees, "", "\'", 0);
  }

  /**
   * degreesToDM
   *
   * @param degrees double
   * @param minDecimalDigits int
   * @return String
   */
  public String degreesToDM(double degrees, int minDecimalDigits)
  {
//    Variant v = new Variant();
	return degreesToDM(degrees, "", "\'", minDecimalDigits);
  }

  /**
   * degreesToDM
   *
   * @param degrees double
   * @param degDelim String
   * @param minDelim String
   * @param minDecimalDigits int
   * @return String
   */
  public String degreesToDM(double degrees, String degDelim, String minDelim, int minDecimalDigits)
  {
	return comDispatcher.process("DegreesToDM", new Variant[]
		{new Variant(degrees), new Variant(degDelim), new Variant(minDelim), new Variant(minDecimalDigits)}).toString();
  }

  /**
   * degreesToDMS
   *
   * @param degrees double
   * @return String
   */
  public String degreesToDMS(double degrees)
  {
	return degreesToDMS(degrees, "", "\'", "\"", 0);
  }

  /**
   * degreesToDMS
   *
   * @param degrees double
   * @param secDecimalDigits int
   * @return String
   */
  public String degreesToDMS(double degrees, int secDecimalDigits)
  {
	return degreesToDMS(degrees, "", "\'", "\"", secDecimalDigits);
  }

  /**
   * degreesToDMS
   *
   * @param degrees double
   * @param degDelim String
   * @param minDelim String
   * @param secDelim String
   * @param secDecimalDigits int
   * @return String
   */
  public String degreesToDMS(double degrees, String degDelim, String minDelim, String secDelim, int secDecimalDigits)
  {
	return comDispatcher.process("DegreesToDMS", new Variant[]
		{new Variant(degrees), new Variant(degDelim), new Variant(minDelim), new Variant(secDelim),
		new Variant(secDecimalDigits)}).toString();
  }

  /**
   * degreesToHM
   *
   * @param degrees double
   * @return String
   */
  public String degreesToHM(double degrees)
  {
    return degreesToHM(degrees, ":", "", 0);
  }

  /**
   * degreesToHM
   *
   * @param degrees double
   * @param minDecimalDigits int
   * @return String
   */
  public String degreesToHM(double degrees, int minDecimalDigits)
  {
    return degreesToHM(degrees, ":", "", minDecimalDigits);
  }


  /**
   * degreesToHM
   *
   * @param degrees double
   * @param hrsDelim String
   * @param minDelim String
   * @param minDecimalDigits int
   */
  public String degreesToHM(double degrees, String hrsDelim, String minDelim, int minDecimalDigits)
  {
	return comDispatcher.process("DegreesToHM", new Variant[]
		{new Variant(degrees), new Variant(hrsDelim), new Variant(minDelim), new Variant(minDecimalDigits)}).toString();
  }

  /**
   * degreesToHMS
   *
   * @param degrees double
   * @return String
   */
  public String degreesToHMS(double degrees)
  {
	return degreesToHMS(degrees, ":", ":", "", 0);
  }

  /**
   * degreesToHMS
   *
   * @param degrees double
   * @param secDecimalDigits int
   * @return String
   */
  public String degreesToHMS(double degrees, int secDecimalDigits)
  {
	return degreesToHMS(degrees, ":", ":", "", secDecimalDigits);
  }

  /**
   * degreesToHMS
   *
   * @param degrees double
   * @param hrsDelim String
   * @param minDelim String
   * @param secDelim String
   * @param secDecimalDigits int
   */
  public String degreesToHMS(double degrees, String hrsDelim, String minDelim, String secDelim, int secDecimalDigits)
  {
	return comDispatcher.process("DegreesToHMS", new Variant[]
		{new Variant(degrees), new Variant(hrsDelim), new Variant(minDelim), new Variant(secDelim),
		new Variant(secDecimalDigits)}).toString();
  }

  /**
   * DMSToDegrees
   *
   * @param dms String
   * @return double
   */
  public double DMSToDegrees(String dms)
  {
	return comDispatcher.process("DMSToDegrees", new Variant[]
		{new Variant(dms)}).toDouble();
  }

  /**
   * HMSToDegrees
   *
   * @param hms String
   * @return double
   */
  public double HMSToDegrees(String hms)
  {
	return comDispatcher.process("HMSToDegrees", new Variant[]
		{new Variant(hms)}).toDouble();
  }

  /**
   * HMSToHours
   *
   * @param hms String
   * @return double
   */
  public double HMSToHours(String hms)
  {
	return comDispatcher.process("HMSToHours", new Variant[]
		{new Variant(hms)}).toDouble();
  }

  /**
   * hoursToHM
   *
   * @param degrees double
   * @return String
   */
  public String hoursToHM(double degrees)
  {
    return hoursToHM(degrees, ":", "", 0);
  }

  /**
   * hoursToHM
   *
   * @param degrees double
   * @param minDecimalDigits int
   * @return String
   */
  public String hoursToHM(double degrees, int minDecimalDigits)
  {
    return hoursToHM(degrees, ":", "", minDecimalDigits);
  }

  /**
   * hoursToHM
   *
   * @param hours double
   * @param hrsDelim String
   * @param minDelim String
   * @param minDecimalDigits int
   * @return String
   */
  public String hoursToHM(double hours, String hrsDelim, String minDelim, int minDecimalDigits)
  {
	return comDispatcher.process("HoursToHM", new Variant[]
		{new Variant(hours), new Variant(hrsDelim), new Variant(minDelim), new Variant(minDecimalDigits)}).toString();
  }

  /**
   * hoursToHMS
   *
   * @param degrees double
   * @return String
   */
  public String hoursToHMS(double degrees)
  {
    return hoursToHMS(degrees, ":", ":", "", 0);
  }

  /**
   * hoursToHMS
   *
   * @param degrees double
   * @param secDecimalDigits int
   * @return String
   */
  public String hoursToHMS(double degrees, int secDecimalDigits)
  {
    return hoursToHMS(degrees, ":", ":", "", secDecimalDigits);
  }

  /**
   * hoursToHMS
   *
   * @param hours double
   * @param hrsDelim String
   * @param minDelim String
   * @param secDelim String
   * @param secDecimalDigits int
   * @return String
   */
  public String hoursToHMS(double hours, String hrsDelim, String minDelim, String secDelim, int secDecimalDigits)
  {
	return comDispatcher.process("HoursToHMS", new Variant[]
		{new Variant(hours), new Variant(hrsDelim), new Variant(minDelim), new Variant(secDelim),
		new Variant(secDecimalDigits)}).toString();
  }

  /**
   * loadDLL
   *
   * @param fileName String
   */
  public void loadDLL(String fileName)
  {
	comDispatcher.process("LoadDLL", new Variant[]
		{new Variant(fileName)}).noParam();
  }

  /**
   * close
   */
  public void close()
  {
	util.release();
  }

  public static void classParser(Object c)
  {
    if(c == null)
    {
      System.out.println("Class==null");
      return;
    }
    System.out.println("Class: " + c.getClass().toString());
    System.out.println("Class: " + c.getClass().toString());
    System.out.println("Class is Array " + (c.getClass().isArray()?"Yes":"No"));
    System.out.println();
    Field [] f = c.getClass().getFields();
    for(int i = 0; i < f.length; i++)
    {
      System.out.println("Field" + i + ": " + f[i]);
    }
    System.out.println();
    Method [] m = c.getClass().getMethods();
    for(int i = 0; i < m.length; i++)
    {
      System.out.println("Method" + i + ": " + m[i]);
    }
    System.out.println();
    Class [] ci = c.getClass().getInterfaces();
    for(int i = 0; i < ci.length; i++)
    {
      System.out.println("Interface" + i + ": " + ci[i].getClass().toString());
    }

  }

}
