/*
 * Copyright (c) 2004 Jeamy Lee, Austria.
 * JASCOM: Ascom for Java
 * Subproject of EOAUI (Extended Open Astronomical User Interface)
 * Version ALPHA 2
 * mailto:jascom.bugs@jeamy.com. All rights reserved.
 * Source and binaries could be found at
 * http://home.textdesign.com/jeamy/jascom/jascom.jar
 * For more information and/or support and bug reports/suggestions use the email above.
 *
 * JASCOM depends on the JACOB (JAva-COM Bridge) libraries
 * programmed by Dan Adler (Copyright (c) 1999) located at
 * http://danadler.com/jacob/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Redistributions in any form must be accompanied by information on
 *    how to obtain complete source code for the JASCOM software.
 *
 * Redistribution of the JASCOM software is not permitted as part of any
 * commercial product that is targeted primarily at Java developers.
 * Such products include, but are not limited to: Java virtual machines,
 * integrated development environments, code libraries, and application
 * server products. Licensing terms for such distribution may be
 * obtained from the copyright holder.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package com.jeamy.jascom.test;

import com.jeamy.jascom.*;

/**
 * Testclass
 *
 * <p>Title: JASCOM: Ascom for Java</p>
 * <p>Description: Java to Ascom Wrapper</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: EOAUI</p>
 * @author Jeamy Lee
 * @version ALPHA 2
 */

public class JAscomDomeTest
{
  public static void main(String[] args)
  {

//	  Initialize the Dome object for the "Dome Simulator Driver"
	Dome dome = new Dome("DomeSim.Dome");

//	  Available methods and properties are described in the
//	  ASCOM Dome Interface Standard Reference
//	  Available at http://ascom-standards.org/index.html
//    and in the ASCOM developer directory tree
//
//    Quick and dirty installation instructions:

//    1. Download and install ASCOM Platform 3.0 Full Setup
//    located at http://ascom-standards.org/downloads.html

//    2. Download jacob.dll from http://danadler.com/jacob/ found in
//    JACOB binary distribution 1.7
//    There is a newer version located in the FILE-Section at
//    http://groups.yahoo.com/group/jacob-project/ (jacob_jre142fix_bin.zip)
//    This version could also be found on home.textdesign.com/jeamy/jascom/jacob_dll.jar
//    Add this file to your Path

//    3. Compile the files, start your Dome Driver and connect it to the Dome
//    or use the ASCOM Dome simulator (prefered for testing).
//    Excecute com.jeamy.jascom.test.JAscomDomeTest for some tests.
//
//    4. Create your Application using JAscom. That's all. Good luck! :)

	try
	{
//	  Test some methods

	  System.out.println("setupDialog() ");
	  dome.setupDialog();

	  System.out.println("\n atHome() ");
	  dome.atHome();
	  Thread.sleep(3000L);

	  System.out.println("\n canFindHome() ");
	  dome.canFindHome();
	  Thread.sleep(3000L);

	  System.out.println("\n connected() ");
	  dome.connected();
	  Thread.sleep(3000L);

	  System.out.println("\n openShutter() ");
	  dome.openShutter();
	  Thread.sleep(3000L);

	  System.out.println("\nhalt() ");
	  dome.slewToAltitude(8);
	  Thread.sleep(3000L);

	  System.out.println("\nmove() ");
	  dome.park();
	  Thread.sleep(3000L);

	} catch(Exception e)
	{
	  e.printStackTrace();
	} finally
	{
	  //release COM object
	  dome.close();
	}
  }
}
