/*
* Copyright (c) 2004 Jeamy Lee, Austria.
* JASCOM: Ascom for Java
* Subproject of EOAUI (Extended Open Astronomical User Interface)
* Version ALPHA 2
* mailto:jascom.bugs@jeamy.com. All rights reserved.
* Source and binaries could be found at
* http://home.textdesign.com/jeamy/jascom/jascom.jar
* For more information and/or support and bug reports use above email.
*
* JASCOM depends on the JACOB (JAva-COM Bridge) libraries
* programmed by Dan Adler (Copyright (c) 1999) located at
* http://danadler.com/jacob/
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
* 3. Redistributions in any form must be accompanied by information on
*    how to obtain complete source code for the JASCOM software.
*
* Redistribution of the JASCOM software is not permitted as part of any
* commercial product that is targeted primarily at Java developers.
* Such products include, but are not limited to: Java virtual machines,
* integrated development environments, code libraries, and application
* server products. Licensing terms for such distribution may be
* obtained from the copyright holder.
*
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE
* FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
* OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
* OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
* OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
* USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*/

package com.jeamy.jascom.wrap;

import java.util.Enumeration;
import com.jeamy.jascom.exceptions.JascomException;

/**
 *
 * <p>Title: JASCOM: Ascom for Java</p>
 * <p>Description: Java to Ascom Wrapper</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: EOAUI</p>
 * @author Jeamy Lee
 * @version ALPHA 2
 */
public final class GuideDirections
{

  private static int size;
  private static GuideDirections first = null;
  private static GuideDirections last = null;

  public final int enumb;
  private String mode;
  private GuideDirections prev;
  private GuideDirections next;

  private GuideDirections(String direction)
  {
    this.mode = direction;
    this.enumb = size++;
    if(first == null)
    {
      first = this;
    }
    if(last != null)
    {
      this.prev = last;
      last.next = this;
    }
    last = this;
  }

  public static final GuideDirections guideNorth = new GuideDirections("guideNorth");
  public static final GuideDirections guideSouth = new GuideDirections("guideSouth");
  public static final GuideDirections guideEast = new GuideDirections("guideEast");
  public static final GuideDirections guideWest = new GuideDirections("guideWest");

  public static GuideDirections getGuideDirections(int type) throws JascomException
  {
    GuideDirections mode = null;
    switch(type)
    {
      case 0:
        mode = GuideDirections.guideNorth;
        break;
      case 1:
        mode = GuideDirections.guideSouth;
        break;
      case 2:
        mode = GuideDirections.guideEast;
        break;
      case 3:
        mode = GuideDirections.guideWest;
        break;
      default:
        throw new JascomException(JascomException.E_GUIDE_DIR_NOT_SUPPORTED, JascomException.E_GUIDE_DIR_NOT_SUPPORTED_S);
    }
    return mode;
  }

  public static GuideDirections first()
  {
    return first;
  }

  public static GuideDirections last()
  {
    return last;
  }

  public GuideDirections prev()
  {
    return this.prev;
  }

  public GuideDirections next()
  {
    return this.next;
  }

  public static int size()
  {
    return size;
  }

  public String toString()
  {
    return this.mode;
  }

  public static Enumeration elements()
  {
    return new Enumeration()
    {
      private GuideDirections curr = first;

      public boolean hasMoreElements()
      {
        return curr != null;
      }

      public Object nextElement()
      {
        GuideDirections n = curr;
        curr = curr.next();
        return n;
      }
    };
  }

}
